Index: uspace/lib/drv/generic/remote_usbhc.c
===================================================================
--- uspace/lib/drv/generic/remote_usbhc.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/drv/generic/remote_usbhc.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -433,5 +433,5 @@
 }
 
-static int callback_out(void *arg, int error, size_t transfered_size)
+static int callback_out(void *arg, int error, size_t transferred_size)
 {
 	async_transaction_t *trans = arg;
@@ -444,5 +444,5 @@
 }
 
-static int callback_in(void *arg, int error, size_t transfered_size)
+static int callback_in(void *arg, int error, size_t transferred_size)
 {
 	async_transaction_t *trans = arg;
@@ -451,5 +451,5 @@
 		if (error == EOK) {
 			error = async_data_read_finalize(trans->data_caller,
-			    trans->buffer, transfered_size);
+			    trans->buffer, transferred_size);
 		} else {
 			async_answer_0(trans->data_caller, EINTR);
Index: uspace/lib/usbhost/include/usb/host/usb_transfer_batch.h
===================================================================
--- uspace/lib/usbhost/include/usb/host/usb_transfer_batch.h	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbhost/include/usb/host/usb_transfer_batch.h	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -80,5 +80,5 @@
 	size_t buffer_size;
 	/** Actually used portion of the buffer */
-	size_t transfered_size;
+	size_t transferred_size;
 
 	/** Indicates success/failure of the communication */
Index: uspace/lib/usbhost/src/bus.c
===================================================================
--- uspace/lib/usbhost/src/bus.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbhost/src/bus.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -572,5 +572,5 @@
 	unsigned done;
 
-	size_t transfered_size;
+	size_t transferred_size;
 	int error;
 } sync_data_t;
@@ -579,9 +579,9 @@
  * Callback for finishing the transfer. Wake the issuing thread.
  */
-static int sync_transfer_complete(void *arg, int error, size_t transfered_size)
+static int sync_transfer_complete(void *arg, int error, size_t transferred_size)
 {
 	sync_data_t *d = arg;
 	assert(d);
-	d->transfered_size = transfered_size;
+	d->transferred_size = transferred_size;
 	d->error = error;
 	fibril_mutex_lock(&d->done_mtx);
@@ -624,5 +624,5 @@
 
 	return (sd.error == EOK)
-		? (ssize_t) sd.transfered_size
+		? (ssize_t) sd.transferred_size
 		: (ssize_t) sd.error;
 }
Index: uspace/lib/usbhost/src/usb_transfer_batch.c
===================================================================
--- uspace/lib/usbhost/src/usb_transfer_batch.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbhost/src/usb_transfer_batch.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -118,5 +118,5 @@
 
 	if (batch->on_complete) {
-		const int err = batch->on_complete(batch->on_complete_data, batch->error, batch->transfered_size);
+		const int err = batch->on_complete(batch->on_complete_data, batch->error, batch->transferred_size);
 		if (err)
 			usb_log_warning("batch %p failed to complete: %s",
Index: uspace/lib/usbdev/src/pipes.c
===================================================================
--- uspace/lib/usbdev/src/pipes.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbdev/src/pipes.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -69,11 +69,11 @@
  * @param[out] data_buffer Buffer for incoming data.
  * @param[in] data_buffer_size Size of the buffer for incoming data (in bytes).
  * @param[out] data_transfered_size Number of bytes that were actually
  *                                  transfered during the DATA stage.
  * @return Error code.
  */
 int usb_pipe_control_read(usb_pipe_t *pipe,
     const void *setup_buffer, size_t setup_buffer_size,
-    void *buffer, size_t buffer_size, size_t *transfered_size)
+    void *buffer, size_t buffer_size, size_t *transferred_size)
 {
 	assert(pipe);
@@ -105,6 +105,6 @@
 	}
 
-	if (rc == EOK && transfered_size != NULL) {
-		*transfered_size = act_size;
+	if (rc == EOK && transferred_size != NULL) {
+		*transferred_size = act_size;
 	}
 
@@ -166,9 +166,9 @@
  * @param[out] buffer Buffer where to store the data.
  * @param[in] size Size of the buffer (in bytes).
  * @param[out] size_transfered Number of bytes that were actually transfered.
  * @return Error code.
  */
 int usb_pipe_read(usb_pipe_t *pipe,
-    void *buffer, size_t size, size_t *size_transfered)
+    void *buffer, size_t size, size_t *size_transferred)
 {
 	assert(pipe);
@@ -200,6 +200,6 @@
 	async_exchange_end(exch);
 
-	if (rc == EOK && size_transfered != NULL) {
-		*size_transfered = act_size;
+	if (rc == EOK && size_transferred != NULL) {
+		*size_transferred = act_size;
 	}
 
@@ -69,11 +69,11 @@
  * @param[out] data_buffer Buffer for incoming data.
  * @param[in] data_buffer_size Size of the buffer for incoming data (in bytes).
- * @param[out] data_transfered_size Number of bytes that were actually
- *                                  transfered during the DATA stage.
+ * @param[out] data_transferred_size Number of bytes that were actually
+ *                                  transferred during the DATA stage.
  * @return Error code.
  */
@@ -166,9 +166,9 @@
  * @param[out] buffer Buffer where to store the data.
  * @param[in] size Size of the buffer (in bytes).
- * @param[out] size_transfered Number of bytes that were actually transfered.
+ * @param[out] size_transferred Number of bytes that were actually transferred.
  * @return Error code.
  */
Index: uspace/lib/usbdev/src/request.c
===================================================================
--- uspace/lib/usbdev/src/request.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbdev/src/request.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -118,5 +118,5 @@
  * @param data_size        Size of the @p data buffer
  *                         (in native endianness).
  * @param actual_data_size Actual size of transfered data
  *                         (in native endianness).
  *
@@ -183,12 +183,12 @@
 
 	uint16_t status_usb_endianess;
-	size_t data_transfered_size;
+	size_t data_transferred_size;
 	int rc = usb_control_request_get(pipe, USB_REQUEST_TYPE_STANDARD,
 	    recipient, USB_DEVREQ_GET_STATUS, 0, uint16_host2usb(index),
-	    &status_usb_endianess, 2, &data_transfered_size);
-	if (rc != EOK) {
-		return rc;
-	}
-	if (data_transfered_size != 2) {
+	    &status_usb_endianess, 2, &data_transferred_size);
+	if (rc != EOK) {
+		return rc;
+	}
+	if (data_transferred_size != 2) {
 		return ELIMIT;
 	}
@@ -314,12 +314,12 @@
 	 */
 	uint8_t tmp_buffer;
-	size_t bytes_transfered;
+	size_t bytes_transferred;
 	rc = usb_request_get_descriptor(pipe, request_type, recipient,
 	    descriptor_type, descriptor_index, language,
-	    &tmp_buffer, sizeof(tmp_buffer), &bytes_transfered);
-	if (rc != EOK) {
-		return rc;
-	}
-	if (bytes_transfered != 1) {
+	    &tmp_buffer, sizeof(tmp_buffer), &bytes_transferred);
+	if (rc != EOK) {
+		return rc;
+	}
+	if (bytes_transferred != 1) {
 		return ELIMIT;
 	}
@@ -340,10 +340,10 @@
 	rc = usb_request_get_descriptor(pipe, request_type, recipient,
 	    descriptor_type, descriptor_index, language,
-	    buffer, size, &bytes_transfered);
+	    buffer, size, &bytes_transferred);
 	if (rc != EOK) {
 		free(buffer);
 		return rc;
 	}
-	if (bytes_transfered != size) {
+	if (bytes_transferred != size) {
 		free(buffer);
 		return ELIMIT;
@@ -118,5 +118,5 @@
  * @param data_size        Size of the @p data buffer
  *                         (in native endianness).
- * @param actual_data_size Actual size of transfered data
+ * @param actual_data_size Actual size of transferred data
  *                         (in native endianness).
  *
Index: uspace/lib/usbvirt/src/ipc_hc.c
===================================================================
--- uspace/lib/usbvirt/src/ipc_hc.c	(revision b3c396907c3dfb9b7afd227215a7bd6a7416d6dd)
+++ uspace/lib/usbvirt/src/ipc_hc.c	(revision db51a6a671d00feb477a7c35b072e80c77fe4a6f)
@@ -50,5 +50,5 @@
  * @param data_buffer Data buffer (DATA stage of control transfer).
  * @param data_buffer_size Size of data buffer in bytes.
  * @param data_transfered_size Number of actually transferred bytes.
  *
  * @return Error code.
@@ -57,5 +57,5 @@
 int usbvirt_ipc_send_control_read(async_sess_t *sess, void *setup_buffer,
     size_t setup_buffer_size, void *data_buffer, size_t data_buffer_size,
-    size_t *data_transfered_size)
+    size_t *data_transferred_size)
 {
 	if (!sess)
@@ -111,6 +111,6 @@
 		return (int) opening_request_rc;
 	
-	if (data_transfered_size != NULL)
-		*data_transfered_size = IPC_GET_ARG2(data_request_call);
+	if (data_transferred_size != NULL)
+		*data_transferred_size = IPC_GET_ARG2(data_request_call);
 	
 	return EOK;
@@ -50,5 +50,5 @@
  * @param data_buffer Data buffer (DATA stage of control transfer).
  * @param data_buffer_size Size of data buffer in bytes.
- * @param data_transfered_size Number of actually transferred bytes.
+ * @param data_transferred_size Number of actually transferred bytes.
  *
  * @return Error code.
